@@ -231,6 +231,9 @@ typedef struct nffile_s {
 	file_header_t		*file_header;	// file header
 	data_block_header_t	*block_header;	// buffer
 	void				*buff_ptr;		// pointer into buffer for read/write blocks/records
+	/* added by libnf patch  */
+	void *lzo_buff;
+	int lzo_initialized;
 	stat_record_t 		*stat_record;	// flow stat record
 	catalog_t			*catalog;		// file catalog
 	int					_compress;		// data compressed flag
